Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: include/gpu/GrContext.h

Issue 1234313002: Make readpixels work on GrTextures (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: fix and more kRT removal Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/gpu/GrContext.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrContext.h
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index 370830e1ad652610eccebc5f4f41a00c81f6fb47..65fac230ccabd8eb7b2a650eba3e62b99b843bd2 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -228,8 +228,8 @@ public:
};
/**
* Reads a rectangle of pixels from a render target.
* @param target the render target to read from.
* @param left left edge of the rectangle to read (inclusive)
* @param top top edge of the rectangle to read (inclusive)
* @param width width of rectangle to read in pixels.
@@ -241,14 +241,13 @@ public:
* @param pixelOpsFlags see PixelOpsFlags enum above.
*
* @return true if the read succeeded, false if not. The read can fail because of an unsupported
- * pixel config or because no render target is currently set and NULL was passed for
- * target.
+ * pixel configs
*/
- bool readRenderTargetPixels(GrRenderTarget* target,
- int left, int top, int width, int height,
- GrPixelConfig config, void* buffer,
- size_t rowBytes = 0,
- uint32_t pixelOpsFlags = 0);
+ bool readSurfacePixels(GrSurface* surface,
+ int left, int top, int width, int height,
+ GrPixelConfig config, void* buffer,
+ size_t rowBytes = 0,
+ uint32_t pixelOpsFlags = 0);
/**
* Writes a rectangle of pixels to a surface.
« no previous file with comments | « no previous file | src/gpu/GrContext.cpp » ('j') | no next file with comments »
@@ -228,8 +228,8 @@ public:
};
/**
- * Reads a rectangle of pixels from a render target.
- * @param target the render target to read from.
+ * Reads a rectangle of pixels from a surface.
+ * @param surface the surface to read from.
* @param left left edge of the rectangle to read (inclusive)
* @param top top edge of the rectangle to read (inclusive)

Powered by Google App Engine
This is Rietveld 408576698